@@ -1,20 +1,18 @@
-from django.db import models
 from tagging.fields import TagField
-from tagging_autocomplete.widgets import TagAutocomplete
 from django.contrib.admin.widgets import AdminTextInputWidget
 
-# The following code is based on models.py file from django-tinymce by Joost Cassee
+from tagging_autocomplete.widgets import TagAutocomplete
+
 
 class TagAutocompleteField(TagField):
     """
-    TagField with autocomplete widget
+    TagField with autocomplete widget.
     """
+
     def formfield(self, **kwargs):
         defaults = {'widget': TagAutocomplete}
         defaults.update(kwargs)
-
-        # As an ugly hack, we override the admin widget
+        # As an ugly hack, we override the admin widget.
         if defaults['widget'] == AdminTextInputWidget:
-            defaults['widget'] = TagAutocomplete
-
+            defaults['widget'] = TagAutocomplete(attrs={'class': 'vTextField'})
         return super(TagAutocompleteField, self).formfield(**defaults)
